========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/openstackdocstheme.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

OpenStack Foundation Sphinx Themes
==================================

Theme and extension support for Sphinx documentation that is published by
OpenStack Foundation projects.

OpenStack docs.openstack.org Sphinx Theme
-----------------------------------------

Theme support for Sphinx documentation that is published to
docs.openstack.org and developer.openstack.org.

Intended for use by OpenStack `projects governed by the Technical Committee`_.

.. _`projects governed by the Technical Committee`: https://governance.openstack.org/tc/reference/projects/index.html

StarlingX docs.starlingx.io Sphinx Theme
-----------------------------------------

Theme support for Sphinx documentation that is published to
docs.starlingx.io.

Intended for use by StarlingX `projects governed by the Technical Steering Committee`_.

.. _`projects governed by the Technical Steering Committee`: https://docs.starlingx.io/governance/reference/projects/index.html

References
----------

* Free software: Apache License, Version 2.0
* Documentation: https://docs.openstack.org/openstackdocstheme/latest/
* Release notes: https://docs.openstack.org/releasenotes/openstackdocstheme/
* Source: https://opendev.org/openstack/openstackdocstheme
* Bugs: https://launchpad.net/openstack-doc-tools
